# VN Rabbit Relinquishment Paper 
# 22 July 2017: final version of script for publication

#### Load libraries ####

library("plyr")
library("dplyr")
library("ggplot2")
library("multcomp")
library("MASS")

#### Load data ####

data_age <- read.csv(file="Nevilleetal_automaticallyextracted_ageandreason.csv",head=TRUE,sep=",")
data_noad  <- read.csv(file="Nevilleetal_manuallyextracted_numadverts_1416.csv",head=TRUE,sep=",")

#### Model 1: Number of adverts ####

data_noad$Year<-as.factor(data_noad$Year)
m1<-glm.nb(No.ads~Website+Cost+Year+Season+Year:Cost+Season:Cost,data=data_noad)
summary(m1)
plot(m1,3)
drop1(m1,test='Chisq')
m1a<-glm.nb(No.ads~Website+Cost+Year+Season,data=data_noad)
drop1(m1a,test='Chisq')

#### Post-hoc: Number of adverts ####

summary(glht(m1a, mcp(Season="Tukey"))) 
summary(glht(m1a, mcp(Year="Tukey"))) 
m1b<-glm.nb(No.ads~Website+Season+Year,data=data_noad[data_noad$Cost=='free',])
summary(glht(m1b, mcp(Season="Tukey"))) 
summary(glht(m1b, mcp(Year="Tukey"))) 
m1c<-glm.nb(No.ads~Website+Season+Year,data=data_noad[data_noad$Cost=='notfree',])
summary(glht(m1c, mcp(Season="Tukey"))) 
summary(glht(m1c, mcp(Year="Tukey"))) 

#### Model 2: Age of rabbits ####

m2<-glm.nb(age~cost+season+reason+cost:season,data=data_age)
summary(m2)
plot(m2,3)
drop1(m2, test='Chisq')
m2a=update(m2, .~. - cost:season)
drop1(m2a, test='Chisq')

#### Post-hoc: Age of rabbits ####

summary(glht(m2a, mcp(season="Tukey"))) 
summary(glht(m2a, mcp(reason="Tukey"))) 
m2b<-glm.nb(age~season+reason,data=data_age[data_age$cost=='free',])
summary(glht(m2b, mcp(season="Tukey"))) 
m2c<-glm.nb(age~season+reason,data=data_age[data_age$cost!='free',])
summary(glht(m2c, mcp(season="Tukey"))) 

#### Plot number of adverts by year and cost ####

no_year.cost<-ddply(data_noad, c('Year','Cost'), summarise, all=mean(No.ads), SD = sd(No.ads), N=length(No.ads), SE = SD/sqrt(N))
labels <- c(free = "Free", notfree = "For Sale")
fig1=ggplot(no_year.cost, aes(x=Year, y=all)) + geom_bar(stat="identity")+ xlim(c(2013.5,2016.5))+
  geom_errorbar(aes(ymin=all-SE, ymax=all+SE), position = position_dodge(0.9), width = .1)  + ylab("Mean number of advertisements") + 
  xlab("") + theme(legend.position="none") + theme_bw() + theme(panel.grid.major = element_blank(),panel.grid.minor = element_blank()) + 
  theme(text = element_text(size=17)) +facet_grid(Cost ~ ., scales="free",labeller=labeller(Cost = labels)) 
fig1

tiff("Figure1.tiff", res=300, units="cm", width=10, height=15)
fig1
dev.off()

#### Plot number of adverts by season and cost ####

no_cost.season<-ddply(data_noad, c('Season','Cost'), summarise, all=mean(No.ads), SD = sd(No.ads), N=length(No.ads), SE = SD/sqrt(N))
labels <- c(free = "Free", notfree = "For Sale")
fig2=ggplot(no_cost.season, aes(x=Season, y=all)) + geom_bar(stat="identity")+ scale_x_discrete(limits = c('Winter','Spring','Summer','Autumn'))+
  geom_errorbar(aes(ymin=all-SE, ymax=all+SE), position = position_dodge(0.9), width = .1)  + ylab("Mean number of advertisements") + 
  xlab("") + theme(legend.position="none") + theme_bw() + theme(panel.grid.major = element_blank(),panel.grid.minor = element_blank()) + 
  theme(text = element_text(size=17)) + facet_grid(Cost ~ ., scales="free",labeller=labeller(Cost = labels)) 
fig2

tiff("Figure2.tiff", res=300, units="cm", width=11, height=15)
fig2
dev.off()

#### Plot number of adverts by season and cost ####

age_cost.season<-ddply(data_age[!is.na(data_age$age),], c('season','cost'), summarise, all=mean(age), SD = sd(age),
                       N=length(age), SE = SD/sqrt(N))
labels <- c(free = "Free", notfree = "For Sale")
fig3=ggplot(age_cost.season, aes(x=season, y=all)) + geom_bar(stat="identity")+ scale_x_discrete(limits = c('Winter','Spring','Summer','Autumn'))+
  geom_errorbar(aes(ymin=all-SE, ymax=all+SE), position = position_dodge(0.9), width = .1)  + ylab("Mean age of rabbits (months)") + 
  xlab("") + theme(legend.position="none") + theme_bw() + theme(panel.grid.major = element_blank(),panel.grid.minor = element_blank()) + 
  theme(text = element_text(size=17)) + ylim(c(0,35))+facet_grid(cost ~ .,labeller=labeller(cost = labels)) 
fig3

tiff("Figure3.tiff", res=300, units="cm", width=11, height=15)
fig3
dev.off()
